/**
 * @file
 * Emoji picker behaviors.
 */

import 'https://cdn.jsdelivr.net/npm/emoji-picker-element@^1/index.js';
import textFieldEdit from 'https://cdn.jsdelivr.net/npm/text-field-edit@^4/index.min.js';

(function (Drupal) {
  Drupal.behaviors.emojiPicker = {
    attach(context, settings) {
      const emojiPicker = document.querySelector('emoji-picker');

      async function loadLocale() {
        if (emojiPicker.locale && emojiPicker.locale !== 'en') {
          // import i18n from 'https://cdn.jsdelivr.net/npm/emoji-picker-element@^1/i18n/fr.js';
          const i18n = await import(
            `https://cdn.jsdelivr.net/npm/emoji-picker-element@^1/i18n/${emojiPicker.locale}.js`
          );
          emojiPicker.i18n = i18n.default;
        }
      }
      loadLocale();

      // Go one level above and search for a text input.
      const field = emojiPicker.parentNode.querySelector(
        '.form-text[data-drupal-selector]',
      );

      const restrictInput = emojiPicker.dataset.drupalRestrictInput;

      // Disallow any other input than emojis by setting the maxLength to 0
      // Enables the user to delete.
      // @see https://stackoverflow.com/a/54372049/2882280
      if (restrictInput) {
        field.dataset.initialMaxLength = field.maxLength ?? 255;
        field.maxLength = 0;
      }

      emojiPicker.addEventListener('emoji-click', (e) => {
        // Set original maxLength.
        if (restrictInput) {
          field.maxLength = field.dataset.initialMaxLength;
        }

        textFieldEdit.insert(field, e.detail.unicode);

        // Restrict it again.
        if (restrictInput) {
          field.maxLength = 0;
        }
      });
    },
  };
})(Drupal);
