<?php

namespace Drupal\emoji_picker\Hook;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\Plugin\Field\FieldWidget\StringTextfieldWidget;
use Drupal\Core\Field\WidgetInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Add third party settings.
 */
#[Hook('field_widget_third_party_settings_form')]
class WidgetThirdPartySettings {

  use StringTranslationTrait;

  /**
   * Implements hook_field_widget_third_party_settings_form().
   *
   * @param \Drupal\Core\Field\WidgetInterface $plugin
   *   The instantiated field widget plugin.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The field definition.
   * @param string $form_mode
   *   The entity form mode.
   * @param array $form
   *   The (entire) configuration form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   *
   * @return array
   *   Form array to be built.
   */
  public function __invoke(
    WidgetInterface $plugin,
    FieldDefinitionInterface $field_definition,
    $form_mode,
    array $form,
    FormStateInterface $form_state,
  ): array {
    if (!$plugin instanceof StringTextFieldWidget) {
      return [];
    }

    $element = [];
    $element['enable'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable emoji picker'),
      '#description' => $this->t('Display a picker with the <a href="@link">emoji-picker-element</a> library.', [
        '@link' => 'https://github.com/nolanlawson/emoji-picker-element',
      ]),
      '#default_value' => $plugin->getThirdPartySetting('emoji_picker', 'enable'),
    ];

    $element['display_picker'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display emoji picker without a tooltip/popover button'),
      '#default_value' => $plugin->getThirdPartySetting('emoji_picker', 'display_picker'),
      '#states' => [
        'invisible' => [
          ':input[name$="[emoji_picker][enable]"]' => [
            'checked' => FALSE,
          ],
        ],
      ],
    ];

    $element['restrict_input'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Restrict input to only emojis'),
      '#description' => $this->t('Only insert new characters with the widget. The backend will check that the string is all emojis.'),
      '#default_value' => $plugin->getThirdPartySetting('emoji_picker', 'restrict_input'),
      '#states' => [
        'invisible' => [
          ':input[name$="[emoji_picker][enable]"]' => [
            'checked' => FALSE,
          ],
        ],
      ],
    ];

    return $element;
  }

}
